'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var _hyperapp = _interopDefault(require('hyperapp'));
var qiitaLogo = _interopDefault(require('@increments/qiita-logo'));

function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var Tooltip_1 = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Tooltip = undefined;



var Tooltip = exports.Tooltip = function Tooltip(_ref) {
  var state = _ref.state,
      length = _ref.length;
  return state.isVisible && (0, _hyperapp.h)(
    "div",
    { style: { left: state.left + "px" }, "class": "slideMode-Tooltip" },
    state.page + "/" + length
  );
};
});

unwrapExports(Tooltip_1);
var Tooltip_2 = Tooltip_1.Tooltip;

function getMagnitudeFromRange(target, x, length) {
  var rect = target.getBoundingClientRect();
  return Math.ceil((x - rect.left) / (rect.width / length))
}

var getMagnitudeFromRange$1 = /*#__PURE__*/Object.freeze({
	getMagnitudeFromRange: getMagnitudeFromRange
});

var QiitaLogo_1 = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.QiitaLogo = undefined;





var QiitaLogo = exports.QiitaLogo = function QiitaLogo() {
  return (0, _hyperapp.h)(
    "svg",
    {
      "class": "slideMode-Dashboard_logo",
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: qiitaLogo.qiitaLogo.viewBox
    },
    (0, _hyperapp.h)(
      "title",
      null,
      "Qiita"
    ),
    (0, _hyperapp.h)("path", { d: qiitaLogo.qiitaLogo.path })
  );
};
});

unwrapExports(QiitaLogo_1);
var QiitaLogo_2 = QiitaLogo_1.QiitaLogo;

var SlideViewer_1 = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SlideViewer = undefined;









var LEFT_KEY = 37;
var RIGHT_KEY = 39;

var SlideViewer = exports.SlideViewer = function SlideViewer(_ref) {
  var state = _ref.state,
      actions = _ref.actions,
      pages = _ref.pages,
      _ref$option = _ref.option,
      option = _ref$option === undefined ? {} : _ref$option;
  var theme = option.theme,
      contentClass = option.contentClass;

  var next = function next() {
    return actions.next(pages.length);
  };
  var prev = actions.prev;

  return (0, _hyperapp.h)(
    "div",
    {
      "class": "slideMode" + (state.isFullScreen ? " fullscreen" : ""),
      oncreate: function oncreate(element) {
        element.customKeyHandler = function (event) {
          if (event.keyCode === LEFT_KEY) {
            prev();
          } else if (event.keyCode === RIGHT_KEY) {
            next();
          }
        };
        addEventListener("keydown", element.customKeyHandler);
      },
      ondestroy: function ondestroy(element) {
        removeEventListener("keydown", element.customKeyHandler);
      }
    },
    (0, _hyperapp.h)(
      "div",
      { "class": "slideMode-Viewer" },
      (0, _hyperapp.h)("div", {
        "class": "slideMode-Viewer_content" + (state.page === 0 ? " slideMode-Viewer_content--firstSlide" : "") + (contentClass ? " " + contentClass : " markdownContent"),
        onclick: function onclick(event) {
          if (event.target.tagName === "IMG" || event.target.tagName === "A") {
            return;
          }

          // We want to use getBoundingClientRect because it always returns
          // the actual rendered element dimensions, even if there are CSS
          // transformations applied to it.
          var rect = event.currentTarget.getBoundingClientRect();

          // Should we transition to the next or the previous slide?
          if (event.clientX - rect.left > rect.width / 2) {
            next();
          } else {
            prev();
          }
        },
        innerHTML: pages[state.page]
      })
    ),
    (0, _hyperapp.h)(Tooltip_1.Tooltip, { state: state.tooltip, length: pages.length }),
    (0, _hyperapp.h)(
      "div",
      {
        "class": "slideMode-Dashboard" + (theme ? " slideMode-Dashboard-" + theme : "")
      },
      (0, _hyperapp.h)(
        "button",
        {
          "class": "slideMode-Dashboard_button slideMode-Dashboard_button--prev " + (theme ? " slideMode-Dashboard_button-" + theme : "") + (state.page !== 0 ? " slideMode-Dashboard_button--clickable" : ""),
          disabled: state.page === 0,
          onclick: actions.prev
        },
        (0, _hyperapp.h)("i", { "class": "fa fa-backward" })
      ),
      (0, _hyperapp.h)(
        "button",
        {
          "class": "slideMode-Dashboard_button slideMode-Dashboard_button--next " + (theme ? " slideMode-Dashboard_button-" + theme : "") + (state.page !== pages.length - 1 ? " slideMode-Dashboard_button--clickable" : ""),
          disabled: state.page === pages.length - 1,
          onclick: function onclick() {
            return actions.next(pages.length);
          }
        },
        (0, _hyperapp.h)("i", { "class": "fa fa-forward" })
      ),
      (0, _hyperapp.h)(
        "span",
        { "class": "slideMode-Dashboard_pageCount" },
        state.page + 1,
        " / ",
        pages.length
      ),
      (0, _hyperapp.h)(
        "div",
        {
          "class": "slideMode-Dashboard_progress" + (theme ? " slideMode-Dashboard_progress-" + theme : ""),
          onmousemove: function onmousemove(event) {
            actions.tooltip.show({
              page: (0, getMagnitudeFromRange$1.getMagnitudeFromRange)(event.currentTarget, event.clientX, pages.length),
              left: event.clientX - event.currentTarget.getBoundingClientRect().left
            });
          },
          onmouseleave: function onmouseleave(event) {
            actions.tooltip.hide();
          },
          onclick: function onclick(event) {
            actions.goto((0, getMagnitudeFromRange$1.getMagnitudeFromRange)(event.currentTarget, event.clientX, pages.length) - 1);
          }
        },
        (0, _hyperapp.h)("div", {
          "class": "slideMode-Dashboard_progressFill" + (theme ? " slideMode-Dashboard_progressFill-" + theme : ""),
          style: {
            width: (state.page + 1) / pages.length * 100 + "%"
          }
        })
      ),
      (0, _hyperapp.h)(
        "button",
        {
          "class": "slideMode-Dashboard_button slideMode-Dashboard_button--fullscreen slideMode-Dashboard_button--clickable" + (theme ? " slideMode-Dashboard_button-" + theme : ""),
          onclick: actions.toggleFullScreen
        },
        (0, _hyperapp.h)("i", { "class": "fa fa-desktop" })
      ),
      (0, _hyperapp.h)(QiitaLogo_1.QiitaLogo, null)
    )
  );
};
});

unwrapExports(SlideViewer_1);
var SlideViewer_2 = SlideViewer_1.SlideViewer;

var slide = {
  state: {
    tooltip: {
      page: 0,
      left: 0,
      isVisible: false
    },
    isFullScreen: false,
    page: 0
  },
  actions: {
    tooltip: {
      show: function (ref) {
        var page = ref.page;
        var left = ref.left;

        return function (state) { return ({
        page: page,
        left: left,
        isVisible: true
      }); };
},
      hide: function () { return ({ isVisible: false }); }
    },
    toggleFullScreen: function () { return function (state) { return ({ isFullScreen: !state.isFullScreen }); }; },
    prev: function () { return function (state) { return ({
      page: state.page <= 0 ? 0 : state.page - 1
    }); }; },
    next: function (length) { return function (state) { return ({
      page: state.page + 1 >= length ? state.page : state.page + 1
    }); }; },
    goto: function (page) { return ({ page: page }); }
  }
};

exports.slide = slide;
exports.SlideViewer = SlideViewer_2;
//# sourceMappingURL=index.js.map
